@@ -1,6 +1,6 @@
 package DBM::Deep::Engine;
 
-use 5.006_000;
+use 5.008_000;
 
 use strict;
 use warnings FATAL => 'all';
@@ -56,6 +56,8 @@ is the following:
 
 =item * setup
 
+=item * clear
+
 =item * begin_work
 
 =item * commit
@@ -77,14 +79,14 @@ Engine::Sector::* hierarchy and dispatch to them.
 =head1 TRANSACTIONS
 
 Transactions in DBM::Deep are implemented using a variant of MVCC. This attempts
-to keep the amount of actual work done against the file low while stil providing
+to keep the amount of actual work done against the file low while still providing
 Atomicity, Consistency, and Isolation. Durability, unfortunately, cannot be done
 with only one file.
 
 =head2 STALENESS
 
 If another process uses a transaction slot and writes stuff to it, then
-terminates, the data that process wrote it still within the file. In order to
+terminates, the data that process wrote is still within the file. In order to
 address this, there is also a transaction staleness counter associated within
 every write.  Each time a transaction is started, that process increments that
 transaction's staleness counter. If, when it reads a value, the staleness
@@ -105,12 +107,14 @@ probably a failure in Consistency as well as Durability.)
 
 Other DBMSes use transaction logs (a separate file, generally) to achieve
 Durability.  As DBM::Deep is a single-file, we would have to do something
-similar to what SQLite and BDB do in terms of committing using synchonized
+similar to what SQLite and BDB do in terms of committing using synchronized
 writes. To do this, we would have to use a much higher RAM footprint and some
-serious programming that make my head hurts just to think about it.
+serious programming that makes my head hurt just to think about it.
 
 =cut
 
+=head1 METHODS
+
 =head2 read_value( $obj, $key )
 
 This takes an object that provides _base_offset() and a string. It returns the
@@ -244,6 +248,7 @@ sub get_next_key {
     # XXX Need to add logic about resetting the iterator if any key in the
     # reference has changed
     unless ( defined $prev_key ) {
+        eval "use " . $self->iterator_class; die $@ if $@;
         $obj->{iterator} = $self->iterator_class->new({
             base_offset => $obj->_base_offset,
             engine      => $self,
@@ -338,10 +343,6 @@ defined sector type.
 
 sub load_sector { $_[0]->sector_type->load( @_ ) }
 
-=head2 clear
-
-=cut
-
 =head2 clear( $obj )
 
 This takes an object that provides _base_offset() and deletes all its 
@@ -349,6 +350,8 @@ elements, returning nothing.
 
 =cut
 
+sub clear { die "clear must be implemented in a child class" }
+
 =head2 cache / clear_cache
 
 This is the cache of loaded Reference sectors.
@@ -377,7 +380,7 @@ Any other value will return false.
 
 sub supports { die "supports must be implemented in a child class" }
 
-=head2 ACCESSORS
+=head1 ACCESSORS
 
 The following are readonly attributes.
 
@@ -387,6 +390,8 @@ The following are readonly attributes.
 
 =item * sector_type
 
+=item * iterator_class
+
 =back
 
 =cut
@@ -394,6 +399,7 @@ The following are readonly attributes.
 sub storage { $_[0]{storage} }
 
 sub sector_type { die "sector_type must be implemented in a child class" }
+sub iterator_class { die "iterator_class must be implemented in a child class" }
 
 # This code is to make sure we write all the values in the $value to the
 # disk and to make sure all changes to $value after the assignment are
