@@ -1,6 +1,6 @@
 package DBM::Deep::Hash;
 
-use 5.006_000;
+use 5.008_000;
 
 use strict;
 use warnings FATAL => 'all';
@@ -9,7 +9,12 @@ no warnings 'recursion';
 use base 'DBM::Deep';
 
 sub _get_self {
-    eval { local $SIG{'__DIE__'}; tied( %{$_[0]} ) } || $_[0]
+    # See the note in Array.pm as to why this is commented out.
+    # eval { local $SIG{'__DIE__'}; tied( %{$_[0]} ) } || $_[0]
+
+    # During global destruction %{$_[0]} might get tied to undef, so we
+    # need to check that case if tied returns false.
+    tied %{$_[0]} or local *@, eval { exists $_[0]{_}; 1 } ? $_[0] : undef
 }
 
 sub _repr { return {} }
@@ -102,7 +107,7 @@ sub first_key { (shift)->FIRSTKEY(@_) }
 sub next_key  { (shift)->NEXTKEY(@_)  }
 
 sub _clear {
-    my $self = shift->_get_self;
+    my $self = shift;
 
     while ( defined(my $key = $self->first_key) ) {
       do {
@@ -118,7 +123,7 @@ sub _copy_node {
     my ($db_temp) = @_;
 
     my $key = $self->first_key();
-    while ($key) {
+    while (defined $key) {
         my $value = $self->get($key);
         $self->_copy_value( \$db_temp->{$key}, $value );
         $key = $self->next_key($key);
