@@ -1,6 +1,6 @@
 package DBM::Deep::Sector::DBI;
 
-use 5.006_000;
+use 5.008_000;
 
 use strict;
 use warnings FATAL => 'all';
@@ -10,9 +10,6 @@ use base qw( DBM::Deep::Sector );
 use DBM::Deep::Sector::DBI::Reference ();
 use DBM::Deep::Sector::DBI::Scalar ();
 
-sub _init {
-}
-
 sub free {
     my $self = shift;
 
@@ -30,7 +27,7 @@ sub load {
     my $self = shift;
     my ($engine, $offset, $type) = @_;
 
-    if ( $type eq 'refs' ) {
+    if ( !defined $type || $type eq 'refs' ) {
         return DBM::Deep::Sector::DBI::Reference->new({
             engine => $engine,
             offset => $offset,
