@@ -1,6 +1,6 @@
 package DBM::Deep::Sector::File::BucketList;
 
-use 5.006_000;
+use 5.008_000;
 
 use strict;
 use warnings FATAL => 'all';
@@ -57,7 +57,7 @@ sub size {
     return $self->{size};
 }
 
-sub free_meth { return '_add_free_blist_sector' }
+sub free_meth { '_add_free_blist_sector' }
 
 sub free {
     my $self = shift;
