@@ -1,6 +1,6 @@
 package DBM::Deep::Storage::DBI;
 
-use 5.006_000;
+use 5.008_000;
 
 use strict;
 use warnings FATAL => 'all';
@@ -57,7 +57,7 @@ sub open {
     ) or die $DBI::error;
 
     # Should we use the same method as done in new() if passed a $dbh?
-    (undef, $self->{driver}) = map lc, DBI->parse_dsn( $self->{dbi}{dsn} );
+    (undef, $self->{driver}) = map defined($_) ? lc($_) : undef, DBI->parse_dsn( $self->{dbi}{dsn} );
 
     return 1;
 }
@@ -92,20 +92,20 @@ sub unlock {
 #    $self->{dbh}->commit;
 }
 
-sub begin_work {
-    my $self = shift;
-    $self->{dbh}->begin_work;
-}
-
-sub commit {
-    my $self = shift;
-    $self->{dbh}->commit;
-}
-
-sub rollback {
-    my $self = shift;
-    $self->{dbh}->rollback;
-}
+#sub begin_work {
+#    my $self = shift;
+#    $self->{dbh}->begin_work;
+#}
+#
+#sub commit {
+#    my $self = shift;
+#    $self->{dbh}->commit;
+#}
+#
+#sub rollback {
+#    my $self = shift;
+#    $self->{dbh}->rollback;
+#}
 
 sub read_from {
     my $self = shift;
